@@ -1,7 +1,7 @@
 from .core import (groupby, remove, concat, concatv, mapcat,
                    frequencies, interpose, first, second, nth, take,
                    drop, rest, get, last, merge_sorted, interleave,
-                   unique, reduceby, identity, intersection, iterable,
-                   distinct, cons, iterate, accumulate)
+                   unique, reduceby, intersection, isiterable,
+                   isdistinct, cons, iterate, accumulate)
 
-from .recipes import countby
+from .recipes import countby, partitionby
